@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.1900';
+our $VERSION = '0.1901';
 
 use Math::Bezier;
 use MIDI::Simple ();
@@ -158,6 +158,18 @@ sub count_in {
 }
 
 
+sub metronome38 {
+    my $self = shift;
+    my $bars = shift || $self->bars;
+
+    for ( 1 .. $bars ) {
+        $self->note( $self->eighth, $self->kick );
+        $self->note( $self->eighth);
+        $self->note( $self->eighth, $self->snare );
+    }
+}
+
+
 sub metronome34 {
     my $self = shift;
     my $bars = shift || $self->bars;
@@ -404,7 +416,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.1900
+version 0.1901
 
 =head1 SYNOPSIS
 
@@ -609,6 +621,13 @@ This method takes the same arguments as L<MIDI::Simple/"Parameters for n/r/noop"
 Play the closed hihat for the number of beats times the given bars.
 If no bars are given, the default times the number of beats is used.
 
+=head2 metronome38
+
+  $d->metronome38;
+  $d->metronome38($bars);
+
+Add a steady 3/8 beat to the score.
+
 =head2 metronome34
 
   $d->metronome34;
